@@ -231,6 +231,11 @@ namespace code {
 			to->markGc(GcCodeRef::relativeHereImm19, 4, (Word)obj);
 		}
 
+		void nopOut(Output *to, Instr *instr) {
+			// According to ARM manual.
+			to->putInt(0xD503201F);
+		}
+
 		void prologOut(Output *to, Instr *instr) {
 			Offset stackSize = instr->src().offset();
 			Int scaled = stackSize.v64() / 8;
@@ -501,7 +506,12 @@ namespace code {
 			case opLabel:
 			case opRelativeLbl: {
 				Int offset = to->offset(src.label()) + src.offset().v64() - to->tell();
-				putLoadStoreImm(to, 0x58, intRegZR(destReg), offset / 4);
+				Bool large = size(destReg).size64() > 4;
+				if (isIntReg(destReg)) {
+					putLoadStoreImm(to, large ? 0x58 : 0x18, intRegZR(destReg), offset / 4);
+				} else {
+					putLoadStoreImm(to, large ? 0x5C : 0x1C, fpReg(destReg), offset / 4);
+				}
 				return false;
 			}
 			default:
@@ -1168,6 +1178,7 @@ namespace code {
 
 		// Note: "mov" is special: we try to merge mov operations.
 		const OpEntry<OutputFn> outputMap[] = {
+			OUTPUT(nop),
 			OUTPUT(prolog),
 			OUTPUT(epilog),
 			OUTPUT(mov),
