@@ -6,7 +6,7 @@
 #include "../Layout.h"
 #include "../Exception.h"
 #include "../UsedRegs.h"
-#include "../PosixEh/FnState.h"
+#include "../FnState.h"
 
 namespace code {
 	namespace arm64 {
@@ -152,7 +152,7 @@ namespace code {
 			for (Nat i = 0; i < activeBlocks->count(); i++) {
 				const ActiveBlock &a = activeBlocks->at(i);
 				*dest << lblOffset(a.pos);
-				*dest << dat(natConst(code::eh::encodeFnState(a.block.key(), a.activated)));
+				*dest << dat(natConst(code::encodeFnState(a.block.key(), a.activated)));
 			}
 
 			// Table size.
@@ -203,11 +203,15 @@ namespace code {
 			Array<Var> *vars = dest->allVars(init);
 			for (Nat i = 0; i < vars->count(); i++) {
 				Var v = vars->at(i);
-				if (!dest->isParam(v))
+
+				// Don't initialize parameters or variables that are marked to not need initialization.
+				if (!dest->isParam(v) && (dest->freeOpt(v) & freeNoInit) == 0)
 					zeroVar(dest, layout->at(v.key()), v.size());
 			}
 
 			if (usingEH) {
+				padCallWithNop(dest);
+
 				// Remember where the block started.
 				Label lbl = dest->label();
 				*dest << lbl;
@@ -287,6 +291,8 @@ namespace code {
 
 			currentBlock = dest->parent(currentBlock);
 			if (usingEH && table) {
+				padCallWithNop(dest);
+
 				Label lbl = dest->label();
 				*dest << lbl;
 				activeBlocks->push(ActiveBlock(currentBlock, activationId, lbl));
@@ -395,6 +401,8 @@ namespace code {
 
 			// We only need to update the block id if this impacts exception handling.
 			if (dest->freeOpt(var) & freeOnException) {
+				padCallWithNop(dest);
+
 				Label lbl = dest->label();
 				*dest << lbl;
 				activeBlocks->push(ActiveBlock(currentBlock, activationId, lbl));
