@@ -183,15 +183,13 @@ namespace code {
 #endif
 		}
 
-#pragma warning(push)
-#pragma warning(disable: 4297) // Warning about exception model on Visual Studio.
-		extern "C" void SHARED_EXPORT throwDivisionException() {
+		// Note: We use EXCEPTION_EXPORT to make the symbol visible on Linux.
+		void EXCEPTION_EXPORT throwDivisionException() {
 			Engine *e = findEngine();
 			if (!e)
 				e = runtime::someEngineUnsafe();
 			throw new (*e) DivisionByZero();
 		}
-#pragma warning(pop)
 
 		void RemoveInvalid::after(Listing *dest, Listing *src) {
 			if (lblDivZero != Label()) {
