@@ -288,7 +288,9 @@ namespace code {
 		Reg unusedRegUnsafe(RegSet *in) {
 			static const Reg candidates[] = {
 				// Scratch registers:
-				ptr11, ptr10, ptr9, ptr8, ptrC, ptrD, ptrSi, ptrDi, ptrA,
+				ptr11, ptr10, ptr9, ptr8, ptrC, ptrD, ptrA,
+				// Registers that need preservation on Windows:
+				ptrSi, ptrDi,
 				// Registers that need preservation:
 				ptrB, ptr12, ptr13, ptr14, ptr15
 			};
@@ -310,30 +312,6 @@ namespace code {
 			return noReg;
 		}
 
-		static const Reg dirtyRegs[] = {
-			rax, rdi, rsi, rdx, rcx, r8, r9, r10, r11,
-			xmm0, xmm1, xmm2, xmm3, xmm4, xmm5, xmm6, xmm7,
-		};
-		const Reg *fnDirtyRegs = dirtyRegs;
-		const size_t fnDirtyCount = ARRAY_COUNT(dirtyRegs);
-
-		static void saveResult(Listing *dest, primitive::PrimitiveKind k, nat &i, nat &r, Offset offset) {
-			static const Reg intReg[2] = { ptrA, ptrD };
-			static const Reg realReg[2] = { xmm0, xmm1 };
-
-			switch (k) {
-			case primitive::none:
-				break;
-			case primitive::integer:
-			case primitive::pointer:
-				*dest << mov(ptrRel(ptrStack, offset), intReg[i++]);
-				break;
-			case primitive::real:
-				*dest << mov(longRel(ptrStack, offset), realReg[r++]);
-				break;
-			}
-		}
-
 		void put(Output *to, OpCode op) {
 			if (op.prefix)
 				to->putByte(op.prefix);
