@@ -6,6 +6,8 @@ namespace code {
 	namespace x64 {
 		STORM_PKG(core.asm.x64);
 
+		class Arena;
+
 		/**
 		 * Parameter information.
 		 */
@@ -32,8 +34,8 @@ namespace code {
 		/**
 		 * Emit code required to perform a function call. Used from 'RemoveInvalid'.
 		 */
-		void emitFnCall(Listing *dest, Operand call, Operand resultPos, TypeDesc *resultType,
-						Bool resultRef, Block currentBlock, RegSet *used, Array<ParamInfo> *params);
+		void emitFnCall(const Arena *arena, Listing *dest, Operand call, Operand resultPos, TypeDesc *resultType,
+						Bool member, Bool resultRef, Block currentBlock, RegSet *used, Array<ParamInfo> *params);
 
 	}
 }
