@@ -1,10 +1,10 @@
 #pragma once
-#include "Params.h"
 #include "Asm.h"
-#include "../Transform.h"
-#include "../OpTable.h"
-#include "../UsedRegs.h"
-#include "../ActiveBlock.h"
+#include "Code/Params.h"
+#include "Code/Transform.h"
+#include "Code/OpTable.h"
+#include "Code/UsedRegs.h"
+#include "Code/ActiveBlock.h"
 
 namespace code {
 	class Binary;
@@ -12,20 +12,22 @@ namespace code {
 	namespace x64 {
 		STORM_PKG(core.asm.x64);
 
+		class Arena;
+
 		/**
 		 * Transform all accesses to local variables into ebp-relative addresses. In the process,
 		 * also generates function prolog and epilog as well as any construction/destruction
 		 * required for the blocks in the listing.
 		 *
-		 * Note: Make sure not to add any extra used registers here, as this may cause the prolog
-		 * and/or epilog to fail preserving some registers.
+		 * Note: Make sure not to add any extra used registers during this transform, as this may
+		 * cause the prolog and/or epilog to fail preserving some registers.
 		 *
 		 * Note: This should be the last transform run on a listing because of the above.
 		 */
 		class Layout : public Transform {
-			STORM_CLASS;
+			STORM_ABSTRACT_CLASS;
 		public:
-			STORM_CTOR Layout();
+			STORM_CTOR Layout(const Arena *arena);
 
 			// Start transform.
 			virtual void STORM_FN before(Listing *dest, Listing *src);
@@ -36,7 +38,35 @@ namespace code {
 			// When done. Adds metadata.
 			virtual void STORM_FN after(Listing *dest, Listing *src);
 
-		private:
+		protected:
+			/**
+			 * Interface that derived classes extend.
+			 */
+
+			// Layout variables, parameters, and spilled registers. The exact layout depends on the
+			// calling convention, so this is implemented in WindowsLayout and PosixLayout
+			// respectively.
+			virtual Array<Offset> *STORM_FN computeLayout(Listing *l, Params *params, Nat spilled) ABSTRACT;
+
+			// Offset of the result parameter (if any).
+			virtual Offset STORM_FN resultParam() ABSTRACT;
+
+			// Save/restore result while emitting 'endblock' statements.
+			virtual void STORM_FN saveResult(Listing *dest) ABSTRACT;
+			virtual void STORM_FN restoreResult(Listing *dest) ABSTRACT;
+
+			// Custom prolog/epilog code.
+			virtual void STORM_FN emitProlog(Listing *dest) ABSTRACT;
+			virtual void STORM_FN emitEpilog(Listing *dest) ABSTRACT;
+
+		protected:
+			/**
+			 * Internal functionality, but accessible to derived classes.
+			 */
+
+			// Arena, for platform-specific concerns.
+			const Arena *arena;
+
 			// Layout of all parameters for this function.
 			Params *params;
 
@@ -61,9 +91,6 @@ namespace code {
 			// Using exception handling here?
 			Bool usingEH;
 
-			// Offset of the result parameter (if any).
-			Offset resultParam();
-
 			// Signature of the transform functions.
 			typedef void (Layout::*TransformFn)(Listing *dest, Listing *src, Nat line);
 
@@ -87,18 +114,16 @@ namespace code {
 			Operand resolve(Listing *src, const Operand &op, const Size &size);
 
 			// Create and destroy blocks.
-			void initBlock(Listing *dest, Block init, Reg reg);
+			void initBlock(Listing *dest, Block init, Operand space);
 			void destroyBlock(Listing *dest, Block destroy, Bool preserveRax, Bool notifyTable);
 			void epilog(Listing *dest, Listing *src, Nat line, Bool preserveRax);
 
 			// Spill parameters to the stack.
+			typedef bool (*SpillPredicate)(const Param &param, const Offset &offset);
 			void spillParams(Listing *dest);
+			void spillParams(Listing *dest, SpillPredicate p);
 		};
 
 
-		// Compute the layout of variables, given a listing, parameters and the number of registers
-		// that need to be spilled into memory in the function prolog and epilog.
-		Array<Offset> *STORM_FN layout(Listing *l, Params *params, Nat spilled);
-
 	}
 }
