@@ -2,6 +2,7 @@
 #include "RemoveInvalid.h"
 #include "Asm.h"
 #include "Params.h"
+#include "Arena.h"
 #include "../Listing.h"
 #include "../UsedRegs.h"
 #include "../Exception.h"
@@ -63,39 +64,65 @@ namespace code {
 			TRANSFORM(ucastf),
 		};
 
-		static bool isComplexParam(Listing *l, Var v) {
-			TypeDesc *t = l->paramDesc(v);
-			if (!t)
+
+		RemoveInvalid::RemoveInvalid(const Arena *arena) : arena(arena) {}
+
+		bool RemoveInvalid::isIndirectParam(Listing *l, Var v) {
+			if (!l->paramDesc(v))
 				return false;
 
-			return as<ComplexDesc>(t) != null;
+			for (Nat i = 0; i < indirectParams->count(); i++)
+				if (v.key() == indirectParams->at(i))
+					return true;
+
+			return false;
 		}
 
-		static bool isComplexParam(Listing *l, Operand op) {
+		bool RemoveInvalid::isIndirectParam(Listing *l, Operand op) {
 			if (op.type() != opVariable)
 				return false;
 
-			return isComplexParam(l, op.var());
+			return isIndirectParam(l, op.var());
 		}
 
-		RemoveInvalid::RemoveInvalid() {}
-
 		void RemoveInvalid::before(Listing *dest, Listing *src) {
 			used = usedRegs(dest->arena, src).used;
 			large = new (this) Array<Operand>();
 			lblLarge = dest->label();
 			params = new (this) Array<ParamInfo>();
 
-			// Set the 'freeIndirect' flag on all complex parameters.
-			Array<Var> *vars = dest->allParams();
-			for (Nat i = 0; i < vars->count(); i++) {
-				Var v = vars->at(i);
-				if (isComplexParam(dest, v)) {
+			// Figure out which parameters are indirect, and set 'freeIndirect' on them all:
+			{
+				indirectParams = new (this) Array<Nat>();
+				Params *layout = arena->createParams(src->member);
+				Array<Var> *vars = dest->allParams();
+
+				for (Nat i = 0; i < vars->count(); i++)
+					layout->add(i, src->paramDesc(vars->at(i)));
+
+				// Now: figure out which parameters need to be modified:
+				for (Nat i = 0; i < layout->totalCount(); i++) {
+					Param p = layout->totalParam(i);
+					if (p.empty())
+						continue;
+					if (p.id() == Param::returnId())
+						continue;
+					if (!p.inMemory())
+						continue;
+
+					// It is indirect!
+					Var v = vars->at(p.id());
+					indirectParams->push(v.key());
+
+					// Also: modify the parameter so that it is freed correctly:
 					FreeOpt flags = dest->freeOpt(v);
-					// Complex parameters are freed by the caller.
-					flags &= ~freeOnException;
-					flags &= ~freeOnBlockExit;
 					flags |= freeIndirection;
+
+					if (!layout->calleeDestroyParams()) {
+						// Parameters are freed by the caller.
+						flags &= ~freeOnException;
+						flags &= ~freeOnBlockExit;
+					}
 					dest->freeOpt(v, flags);
 				}
 			}
@@ -112,9 +139,15 @@ namespace code {
 			case op::jmp:
 				// Nothing needed. We deal with these later on in the chain.
 				break;
+			case op::fnParam:
+			case op::fnParamRef:
+				i = extractNumbers(i);
+				// We deal with indirect parameters in the fnParam code. The generic code breaks if
+				// there is more than one parameter that needs to be dealt with.
+				break;
 			default:
 				i = extractNumbers(i);
-				i = extractComplex(dest, i, line);
+				i = extractIndirectParams(dest, i, line);
 				break;
 			}
 
@@ -136,11 +169,33 @@ namespace code {
 			}
 		}
 
+		static TypeInstr *isFnParam(Instr *i) {
+			if (i->op() == op::fnParam)
+				return as<TypeInstr>(i);
+			return null;
+		}
+
 		Instr *RemoveInvalid::extractNumbers(Instr *i) {
 			Operand src = i->src();
-			if (src.type() == opConstant && src.size() == Size::sWord && !singleInt(src.constant())) {
-				i = i->alterSrc(longRel(lblLarge, Offset::sWord*large->count()));
-				large->push(src);
+			if (src.type() == opConstant) {
+				if (src.size() == Size::sWord && !singleInt(src.constant())) {
+					// Modify if 64-bits, and the value is not small enough to be truncated...
+					i = i->alterSrc(longRel(lblLarge, Offset::sWord*large->count()));
+					large->push(src);
+				} else if (TypeInstr *t = isFnParam(i)) {
+					// ...or if we are in the context of a function parameter for a float. This is
+					// since the function call code would otherwise sometimes generate 'move xmmX,
+					// <imm>', which is not supported. Note: this particular case only happens for
+					// 32-bit floats, so we need some shoehorning into the existing code here, as it
+					// is intended for 64-bit literals.
+					if (PrimitiveDesc *p = as<PrimitiveDesc>(t->type)) {
+						if (p->v.kind() == primitive::real) {
+							i = i->alterSrc(intRel(lblLarge, Offset::sWord*large->count()));
+							// Extend to word to not mess up alignment of literals.
+							large->push(wordConst(src.constant()));
+						}
+					}
+				}
 			}
 
 			// Labels are also constants.
@@ -153,10 +208,10 @@ namespace code {
 			return i;
 		}
 
-		Instr *RemoveInvalid::extractComplex(Listing *to, Instr *i, Nat line) {
-			// Complex parameters are passed as a pointer. Dereference these by inserting a 'mov' instruction.
+		Instr *RemoveInvalid::extractIndirectParams(Listing *to, Instr *i, Nat line) {
+			// Some parameters are passed as pointers. Dereference them by inserting a 'mov' instruction.
 			RegSet *regs = used->at(line);
-			if (isComplexParam(to, i->src())) {
+			if (isIndirectParam(to, i->src())) {
 				const Operand &src = i->src();
 				Reg reg = asSize(unusedReg(regs), Size::sPtr);
 				regs = new (this) RegSet(*regs);
@@ -166,7 +221,7 @@ namespace code {
 				i = i->alterSrc(xRel(src.size(), reg, src.offset()));
 			}
 
-			if (isComplexParam(to, i->dest())) {
+			if (isIndirectParam(to, i->dest())) {
 				const Operand &dest = i->dest();
 				Reg reg = asSize(unusedReg(regs), Size::sPtr);
 				*to << mov(reg, ptrRel(dest.var(), Offset()));
@@ -250,13 +305,38 @@ namespace code {
 			*dest << instr;
 		}
 
+		static Reg fnParamUnusedReg(RegSet *regs, Array<ParamInfo> *params) {
+			// We need to be more conservative when working with fnParam and fnParamRef.
+			for (Nat i = 0; i < params->count(); i++) {
+				const Operand &src = params->at(i).src;
+				if (src.hasRegister())
+					regs->put(src.reg());
+			}
+
+			return asSize(unusedReg(regs), Size::sPtr);
+		}
+
 		void RemoveInvalid::fnParamTfm(Listing *dest, Instr *instr, Nat line) {
 			TypeInstr *i = as<TypeInstr>(instr);
 			if (!i) {
 				throw new (this) InvalidValue(S("Expected a TypeInstr for 'fnParam'."));
 			}
 
-			params->push(ParamInfo(i->type, i->src(), false));
+			const Operand &src = i->src();
+			if (isIndirectParam(dest, src)) {
+				// As long as the offset is zero, we can just set the reference parameter and be
+				// happy.
+				if (src.offset() == Offset()) {
+					params->push(ParamInfo(i->type, ptrRel(src.var(), Offset()), true));
+				} else {
+					// Otherwise, we need a temporary...
+					Reg tmp = fnParamUnusedReg(used->at(line), params);
+					*dest << mov(tmp, ptrRel(src.var(), Offset()));
+					params->push(ParamInfo(i->type, xRel(src.size(), tmp, src.offset()), true));
+				}
+			} else {
+				params->push(ParamInfo(i->type, src, false));
+			}
 		}
 
 		void RemoveInvalid::fnParamRefTfm(Listing *dest, Instr *instr, Nat line) {
@@ -265,7 +345,14 @@ namespace code {
 				throw new (this) InvalidValue(S("Expected a TypeInstr for 'fnParamRef'."));
 			}
 
-			params->push(ParamInfo(i->type, i->src(), true));
+			Operand src = i->src();
+			if (isIndirectParam(dest, src)) {
+				// We need a temporary...
+				Reg tmp = fnParamUnusedReg(used->at(line), params);
+				*dest << mov(tmp, ptrRel(src.var(), Offset()));
+				src = tmp;
+			}
+			params->push(ParamInfo(i->type, src, true));
 		}
 
 		void RemoveInvalid::fnCallTfm(Listing *dest, Instr *instr, Nat line) {
@@ -274,7 +361,7 @@ namespace code {
 				throw new (this) InvalidValue(S("Using a fnCall that was not created properly."));
 			}
 
-			emitFnCall(dest, t->src(), t->dest(), t->type, false, currentBlock, used->at(line), params);
+			emitFnCall(arena, dest, t->src(), t->dest(), t->type, t->member, false, currentBlock, used->at(line), params);
 			params->clear();
 		}
 
@@ -284,7 +371,7 @@ namespace code {
 				throw new (this) InvalidValue(S("Using a fnCall that was not created properly."));
 			}
 
-			emitFnCall(dest, t->src(), t->dest(), t->type, true, currentBlock, used->at(line), params);
+			emitFnCall(arena, dest, t->src(), t->dest(), t->type, t->member, true, currentBlock, used->at(line), params);
 			params->clear();
 		}
 
