@@ -7,7 +7,7 @@
 #include "LayoutVars.h"
 #include "Asm.h"
 #include "AsmOut.h"
-#include "Seh.h"
+#include "Code/WindowsEh/Seh.h"
 
 namespace code {
 	namespace x86 {
@@ -24,7 +24,7 @@ namespace code {
 
 		Listing *Arena::transform(Listing *l) const {
 #if defined(WINDOWS) && defined(X86)
-			activateInfo();
+			code::eh::activateWindowsInfo(engine());
 #endif
 
 			if (has64(l)) {
@@ -53,8 +53,8 @@ namespace code {
 			return new (this) LabelOutput(4);
 		}
 
-		CodeOutput *Arena::codeOutput(Binary *owner, Array<Nat> *offsets, Nat size, Nat refs) const {
-			return new (this) CodeOut(owner, offsets, size, refs);
+		CodeOutput *Arena::codeOutput(Binary *owner, LabelOutput *size) const {
+			return new (this) CodeOut(owner, size->offsets, size->size, size->refs);
 		}
 
 		void Arena::removeFnRegs(RegSet *from) const {
