@@ -34,7 +34,7 @@ namespace storm {
 			// Cast penalty. Used to deduce parameter types for the function if none were provided.
 			virtual Int STORM_FN castPenalty(Value to);
 
-		protected:
+			// Output.
 			virtual void STORM_FN toS(StrBuf *to) const;
 
 		private:
