@@ -719,13 +719,7 @@ namespace storm {
 			return f.result();
 		}
 
-		// Recompute!
-		forceLoad();
-		mySize = superSize();
-		if (layout) {
-			// If we do not have a layout, we do not have any variables.
-			mySize = layout->doLayout(mySize);
-		}
+		mySize = createSize();
 
 		// Since we have computed our size, it means that we can be instantiated. Because of that,
 		// make sure that the destructor is compiled now. Otherwise, it might be compiled during
@@ -736,6 +730,19 @@ namespace storm {
 		return mySize;
 	}
 
+	Size Type::createSize() {
+		// Recompute the size!
+		forceLoad();
+		mySize = superSize();
+
+		// If we do not have a layout, we do not have any variables.
+		if (layout) {
+			mySize = layout->doLayout(mySize);
+		}
+
+		return mySize;
+	}
+
 	VTable *Type::vtable() {
 		// Don't bother if we're a value or we don't have a vtable yet.
 		if (!myVTable || value())
