@@ -10,8 +10,10 @@ namespace storm {
 		static const EngineFwdShared fwd = {
 			&runtime::typeHandle,
 			&runtime::voidHandle,
+			&runtime::refObjHandle,
 			&runtime::typeOf,
 			&runtime::gcTypeOf,
+			&runtime::typeGc,
 			&runtime::typeName,
 			&runtime::typeIdentifier,
 			&runtime::fromIdentifier,
@@ -24,7 +26,9 @@ namespace storm {
 			&runtime::allocBuffer,
 			&runtime::allocObject,
 			&runtime::allocArray,
+			&runtime::allocArrayRehash,
 			&runtime::allocWeakArray,
+			&runtime::allocWeakArrayRehash,
 			&runtime::allocCode,
 			&runtime::codeSize,
 			&runtime::codeRefs,
@@ -37,7 +41,7 @@ namespace storm {
 			&runtime::postStdRequest,
 			&runtime::cloneObject,
 			&runtime::cloneObjectEnv,
-			&runtime::someEngine,
+			&runtime::someEngineUnsafe,
 
 			// Others.
 			&os::currentThreadData,
@@ -55,4 +59,12 @@ namespace storm {
 
 		return fwd;
 	}
+
+	namespace runtime {
+		Engine &someEngine() {
+			Engine *e = someEngineUnsafe();
+			assert(e, L"Thread was not associated with an engine!");
+			return *e;
+		}
+	}
 }
