@@ -172,9 +172,16 @@ namespace storm {
 		STORM_VALUE;
 	public:
 		STORM_CTOR SerializedMember(Str *name, Type *type);
+		STORM_CTOR SerializedMember(Str *name, Type *type, MAYBE(FnBase *) init);
 
+		// Name of the member.
 		Str *name;
+
+		// Type of the member.
 		Type *type;
+
+		// Default initialization, if any.
+		MAYBE(FnBase *) init;
 	};
 
 	/**
@@ -192,6 +199,7 @@ namespace storm {
 
 		// Add a member.
 		void STORM_FN add(Str *name, Type *type);
+		void STORM_FN add(Str *name, Type *type, MAYBE(FnBase *) init);
 		void add(const wchar *name, Type *type);
 
 		// Number of members.
@@ -209,6 +217,9 @@ namespace storm {
 	private:
 		// Names of the members.
 		Array<Str *> *names;
+
+		// Initialization pointers.
+		Array<FnBase *> *inits;
 	};
 
 	// C++ helper:
@@ -289,11 +300,19 @@ namespace storm {
 	class EXCEPTION_EXPORT SerializationError : public Exception {
 		STORM_EXCEPTION;
 	public:
-		SerializationError(const wchar *msg) {
+	};
+
+	/**
+	 * Format errors during serialization. Contains a message and a stack trace for debugging.
+	 */
+	class EXCEPTION_EXPORT SerializationFormatError : public SerializationError {
+		STORM_EXCEPTION;
+	public:
+		SerializationFormatError(const wchar *msg) {
 			w = new (this) Str(msg);
 			saveTrace();
 		}
-		STORM_CTOR SerializationError(Str *msg) {
+		STORM_CTOR SerializationFormatError(Str *msg) {
 			w = msg;
 			saveTrace();
 		}
@@ -308,7 +327,7 @@ namespace storm {
 	/**
 	 * End of stream while reading from an object stream. Does not save a trace.
 	 */
-	class EXCEPTION_EXPORT EndOfStream : public Exception {
+	class EXCEPTION_EXPORT EndOfStream : public SerializationError {
 		STORM_EXCEPTION;
 	public:
 		STORM_CTOR EndOfStream() {}
@@ -318,6 +337,34 @@ namespace storm {
 		}
 	};
 
+	/**
+	 * Size limit exceeded during deserialization.
+	 */
+	class EXCEPTION_EXPORT SizeLimitReached : public SerializationError {
+		STORM_EXCEPTION;
+	public:
+		STORM_CTOR SizeLimitReached(Str *type, Nat size, Nat budget)
+			: type(type), size(size), budget(budget) {}
+
+		SizeLimitReached(const wchar *type, Nat size, Nat budget)
+			: type(new (engine()) Str(type)), size(size), budget(budget) {}
+
+		virtual void STORM_FN message(StrBuf *to) const {
+			*to << S("Size limit reached: trying to allocate ") << type;
+			if (size == 0) {
+				*to << S(". This would exceed the limit of ") << budget << S(" bytes.");
+			} else {
+				*to << S(" of ") << size
+					<< S(" bytes, which is larger than the current limit of ") << budget
+					<< S(" bytes.");
+			}
+		}
+	private:
+		Str *type;
+		Nat size;
+		Nat budget;
+	};
+
 	/**
 	 * Input stream for objects.
 	 *
@@ -358,6 +405,48 @@ namespace storm {
 		// Close the underlying stream.
 		void STORM_FN close() { from->close(); }
 
+		// Check array allocation. Expected to be called by types that allocate arrays separately by
+		// themselves. May throw an exception.
+		void STORM_FN checkArrayAlloc(Nat elemSize, Nat count);
+
+		// Maximum total size to allow for top-level read operations. If the in-memory size of the
+		// object would exceed this number, then an exception is thrown instead, and reading is
+		// aborted early. If this happens, the input stream is left in an intermediate state, and
+		// further reads can not be made reliably. We don't try to skip the malformed data, as the
+		// intent of this property is to guard against malformed data from possibly malicious
+		// sources. The default value is 4GiB.
+		Nat maxReadSize;
+
+		// Maximum size to allow for any individual array allocations. This value is provided in
+		// addition to 'maxSize' to control the size of individual allocations to some degree. Due
+		// to the existence of ambiguous references, the garbage collector might fail to reclaim
+		// some allocations. Large allocations thereby have a larger risk of being retained, which
+		// could in turn lead to out-of-memory conditions whenever a large object is allocated, even
+		// if it is not used afterwards. The default value is 4GiB.
+		Nat maxArraySize;
+
+		// Get/set the size of type descriptions. This is to put an upper limit on the metadata
+		// stored by this object in order to disallow out-of-memory conditions from malformed type
+		// descriptions. Default is 4GiB.
+		Nat STORM_FN maxTypeDescSize() const { return typeDescLimit; }
+		void STORM_FN maxTypeDescSize(Nat size);
+
+		// Current size of our type description.
+		Nat STORM_FN typeDescSize() const { return typeDescCurrent; }
+
+		// Set all sizes to the specified number.
+		void STORM_ASSIGN maxSize(Nat max) {
+			maxReadSize = max;
+			maxArraySize = max;
+			maxTypeDescSize(max);
+		}
+
+		// Get the remaining size budget of the last object that was read.
+		Nat STORM_FN lastReadBudget() const { return readSizeBudget; }
+
+		// Get the size of the last read object (assuming that 'maxReadSize' was not changed).
+		Nat STORM_FN lastReadSize() const { return maxReadSize - lastReadBudget(); }
+
 	private:
 		// Description of a member.
 		//
@@ -366,27 +455,43 @@ namespace storm {
 		class Member {
 			STORM_VALUE;
 		public:
-			// Create.
+			// Create a regular member: read 'name' with 'type' from the stream in some fashion.
 			Member(Str *name, Nat type);
 
+			// Create a default-initialized member. We don't use 'name', but instead store the initializer.
+			Member(FnBase *init);
+
 			// Create a copy with a different 'read' member.
 			Member(const Member &o, Int read);
 
 			// Name of the member.
-			MAYBE(Str *) name;
+			Str *name() const {
+				return read == -1 ? null : (Str *)data;
+			}
+
+			// Initializer of the member.
+			FnBase *init() const {
+				return read == -1 ? (FnBase *)data : null;
+			}
 
 			// Type of the member.
 			Nat type;
 
 			// How to read the member:
-			// =0: just read the member as usual.
-			// <0: read this member and push it to temporary storage. Do not return it immediately.
-			// >0: read the member from an object previously saved in temporary storage, not from the stream.
+			// = 0: Read it immediately, as usual.
+			// =-1: Use default value.
+			// =-2: Read this member and push it onto temporary storage.
+			// =-3: Read this member and ignore it. Must only be used at the end.
+			// > 0: Read this member from temporary storage at 'read - 1'.
 			// This allows reading members in a different order compared to what is expected
 			// by the constructor of the object we're constructing. It does, however, incur
 			// additional memory allocation in cases where we need to reorder members. This is
 			// fine since we expect that case to be rare.
 			Int read;
+
+		private:
+			// Data. Either the name of the member, or a function ptr (if read = -1).
+			UNKNOWN(PTR_GC) void *data;
 		};
 
 		// Description of a type. Contains a pointer to an actual type once we know that.
@@ -482,6 +587,15 @@ namespace storm {
 		// Directory of known type ids.
 		Map<Nat, Desc *> *typeIds;
 
+		// Limit of type desc size.
+		Nat typeDescLimit;
+
+		// Current size of the type description data, to guard against overflows.
+		Nat typeDescCurrent;
+
+		// Current remaining size budget of the top-level object that is currently being read.
+		Nat readSizeBudget;
+
 		// Information from 'start'.
 		struct Info {
 			// Type we're expecting.
@@ -493,8 +607,10 @@ namespace storm {
 
 		// Start deserialization of an object. As a part of the process, figures out which object to
 		// read and returns its id. Will also make sure to read any objects that are supposed to be
-		// stored in temporary storage if necessary.
-		Info start();
+		// stored in temporary storage if necessary. Parameter indicates where to store values if we
+		// are trying to load a value (so we can skip the Variant if we are default-initializing
+		// value types).
+		Info start(PTR_GC valueOut);
 
 		// Get the description for an object id, reading it if necessary.
 		Desc *findInfo(Nat id);
@@ -509,7 +625,7 @@ namespace storm {
 		void validateMaybe(Desc *desc);
 
 		// Read an object into a variant.
-		Variant readClass(Nat type);
+		Variant readObject(Nat type);
 
 		// Read a value (internal version, does not call 'start').
 		void readValueI(Desc *type, void *out);
@@ -519,6 +635,12 @@ namespace storm {
 
 		// Clear object ids.
 		void clearObjects();
+
+		// Check size of type descriptions. Add 'current' to it.
+		void checkTypeDescSize(Nat add);
+
+		// Check total allocation size.
+		void checkAllocSize(Nat add);
 	};
 
 
