@@ -322,7 +322,10 @@ namespace storm {
 		template <class U>
 		Failure c(...); // all varargs, last resort to avoid errors
 
-		// Helper to check for whether we have an overload for const or non-const versions:
+#if defined(VISUAL_STUDIO) && VISUAL_STUDIO < 2010
+		// Helper to check for whether we have an overload for const or non-const versions: The
+		// older MSVC compilers are a bit finnicky here. The exact version is a guess. I do not have
+		// access to all of them to test.
 		template <class T>
 		struct HasToS {
 			enum {
@@ -331,6 +334,23 @@ namespace storm {
 			};
 		};
 
+#else
+
+		// Interestingly, the "old" version fails for newer MSVC versions but works in GCC and
+		// CLANG. It seems like the body is instantiated outside of a SFINAE context, so we see
+		// errors from toS() being protected, etc. from that.
+		template <class T,
+				  size_t regularSize = sizeof(r<T>(0, static_cast<short>(1))),
+				  size_t constSize = sizeof(c<T>(0, static_cast<short>(1)))>
+		struct HasToS {
+			enum {
+				regular = regularSize == sizeof(Success),
+				onlyConst = constSize == sizeof(Success),
+			};
+		};
+
+#endif
+
 		// Functions that actually call the implementation. Works like above:
 		template <class T>
 		void callRegularI(StrBuf *to, T &value, void (T::*)(StrBuf *) const, short) {
@@ -398,7 +418,6 @@ namespace storm {
 		}
 	}
 
-
 	// Operator <<, for non-const variants:
 	template <class T>
 	typename EnableIf<tos_impl::HasToS<T>::regular, StrBuf &>::t
@@ -414,4 +433,5 @@ namespace storm {
 		tos_impl::callConst(&to, value);
 		return to;
 	}
+
 }
