@@ -2,6 +2,7 @@
 #include "Utils/Memory.h"
 #include "Utils/Bitwise.h"
 #include "Utils/Templates.h"
+#include "Utils/Cache.h"
 #include "Core/GcType.h"
 #include "Core/GcCode.h"
 #include "Scan.h"
@@ -403,6 +404,37 @@ namespace storm {
 			return alignAlloc(headerSize + code + FMT_CHECK_BYTES + sizeRefs(refs) + FMT_CHECK_BYTES);
 		}
 
+		// These functions are replicas of the size functions above, but take care to check for
+		// overflow. As such, they are slightly more expensive than the 'plain' counterparts. They
+		// return 0 in case of an overflow.
+		static inline size_t overflowSizeObj(const GcType *type) {
+			size_t result = sizeObj(type);
+			// Note: unsigned overflow *is* well defined.
+			if (result < type->stride)
+				return 0;
+			return result;
+		}
+		static inline size_t overflowSizeArray(const GcType *type, size_t count) {
+			size_t dataSize;
+			if (!multiplyOverflow(type->stride, count, dataSize))
+				return 0;
+			size_t result = alignAlloc(headerSize + arrayHeaderSize + dataSize + FMT_CHECK_BYTES);
+			if (result < dataSize)
+				return 0;
+			return result;
+		}
+		static inline size_t overflowSizeCode(size_t code, size_t refs) {
+			size_t refSize;
+			if (!multiplyOverflow(sizeof(GcCodeRef), refs, refSize))
+				return 0;
+			refSize += sizeof(GcCode) - sizeof(GcCodeRef);
+			size_t result = alignAlloc(headerSize + code + FMT_CHECK_BYTES + refSize + FMT_CHECK_BYTES);
+			if (result < refSize)
+				return 0;
+			return result;
+		}
+
+
 		// Get a pointer to the references inside a code allocation (stored immediately after the code itself).
 		static inline GcCode *refsCode(Obj *obj) {
 			size_t code = objCodeSize(obj);
@@ -955,16 +987,6 @@ namespace storm {
 						// Scan the code segment.
 						GcCode *c = refsCode(o);
 
-						// Scan our self-pointer to make sure that this object will be scanned
-						// whenever it is moved.
-						r = fix12(s, &c->reserved);
-						if (r != Result())
-							return r;
-
-#ifdef SLOW_DEBUG
-						dbg_assert(c->reserved == at, L"Invalid self-pointer!");
-#endif
-
 						for (size_t i = 0; i < c->refCount; i++) {
 							GcCodeRef &ref = c->refs[i];
 #ifdef SLOW_DEBUG
@@ -978,6 +1000,26 @@ namespace storm {
 							}
 						}
 
+						// Scan our self-pointer to make sure that this object will be scanned
+						// whenever it is moved. We do this after the references to ensure that
+						// this will flush the data cache properly as a bonus.
+						if (s.fix1(c->reserved)) {
+							void *old = c->reserved;
+							if ((r = s.fix2(&c->reserved)) != Result())
+								return r;
+							if (old != c->reserved) {
+								// Note: It is important that we use "real" pointers, especially for
+								// the "next" member. Otherwise, we might clear the first word in
+								// the next row of objects, and that object might be in another page
+								// that is protected.
+								invalidateICache(fromClient(at), fromClient(next));
+							}
+						}
+
+#ifdef SLOW_DEBUG
+						dbg_assert(c->reserved == at, L"Invalid self-pointer!");
+#endif
+
 						// Update the pointers in the code blob as well.
 						gccode::updatePtrs(at, c);
 					} else {
