@@ -25,7 +25,11 @@ namespace storm {
 	};
 
 	GcImpl::GcImpl(size_t initialArenaSize, Nat finalizationInterval)
-		: arena(initialArenaSize, generations, ARRAY_COUNT(generations)) {}
+		: arena(initialArenaSize, generations, ARRAY_COUNT(generations)) {
+#ifdef STORM_GC_EH_CALLBACK
+#error "SMM does not support EH callbacks as needed by this platform!"
+#endif
+	}
 
 	void GcImpl::destroy() {
 		arena.destroy();
@@ -172,6 +176,10 @@ namespace storm {
 		return result;
 	}
 
+	void *GcImpl::allocArrayRehash(const GcType *type, size_t count) {
+		return allocArray(type, count);
+	}
+
 	void *GcImpl::allocWeakArray(const GcType *type, size_t count) {
 		size_t size = fmt::overflowSizeArray(type, count);
 		if (size == 0)
@@ -192,6 +200,10 @@ namespace storm {
 		return result;
 	}
 
+	void *GcImpl::allocWeakArrayRehash(const GcType *type, size_t count) {
+		return allocWeakArray(type, count);
+	}
+
 	Bool GcImpl::liveObject(RootObject *obj) {
 		// All objects are destroyed promptly by us, so we don't need this functionality.
 		return true;
