@@ -265,7 +265,7 @@ namespace gui {
 		DispatchMessage(&msg);
 	}
 
-	MsgResult App::handleMessage(HWND hwnd, const Message &msg) {
+	MsgResult App::handleMessageI(HWND hwnd, const Message &msg, Window *&found) {
 		if (!currentEngine) {
 			WARNING(L"No current engine. Ignoring " << msg << L".");
 			return noResult();
@@ -287,6 +287,7 @@ namespace gui {
 
 		// Try to post it to a window.
 		Window *w = app->windows->get(Handle(hwnd), app->creating);
+		found = w;
 		if (!w) {
 			WARNING(L"Unknown window: " << hwnd << L", ignoring " << msg << L".");
 			return noResult();
@@ -310,12 +311,35 @@ namespace gui {
 		return r;
 	}
 
-	LRESULT WINAPI App::windowProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam) {
-		MsgResult r = handleMessage(hwnd, Message(msg, wParam, lParam));
-		if (r.any)
-			return r.result;
+	LRESULT App::handleMessage(HWND hwnd, const Message &msg, DefaultWndProc defProc) {
+		Window *found = null;
+		MsgResult r = handleMessageI(hwnd, msg, found);
 
-		return DefWindowProc(hwnd, msg, wParam, lParam);
+		// Dispatch to default if necessary:
+		LRESULT finalResult = 0;
+		if (r.any) {
+			finalResult = r.result;
+		} else if (defProc) {
+			finalResult = (*defProc)(hwnd, msg.msg, msg.wParam, msg.lParam);
+		}
+
+		if (found && r.notify) {
+			found->afterMessage(msg);
+		}
+
+		return finalResult;
+	}
+
+	LRESULT WINAPI App::windowProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam) {
+		return handleMessage(hwnd, Message(msg, wParam, lParam), &DefWindowProc);
+	}
+
+	LRESULT WINAPI App::subclassProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam, UINT_PTR subclass, DWORD_PTR refData) {
+		return handleMessage(hwnd, Message(msg, wParam, lParam), &DefSubclassProc);
+	}
+
+	void App::subclass(HWND handle) {
+		SetWindowSubclass(handle, &App::subclassProc, 1, NULL);
 	}
 
 	ATOM App::registerWindowClass() {
@@ -339,7 +363,7 @@ namespace gui {
 		wc.hIcon = icon;
 		wc.hIconSm = icon;
 		wc.hCursor = LoadCursor(NULL, IDC_ARROW);
-		wc.hbrBackground = (HBRUSH)(COLOR_BTNFACE + 1);
+		wc.hbrBackground = (HBRUSH)(windowBackground + 1);
 		wc.lpszMenuName = 0;
 		wc.lpszClassName = L"StormGui";
 
