@@ -90,6 +90,10 @@ namespace gui {
 
 		// Called after a modal dialog is shown, indicating that the modal message loop is done.
 		void afterDialog();
+
+		// Subclass a window (typically a standardcontrol). Makes it so that we can intercept all
+		// window messages.
+		void subclass(HWND handle);
 #endif
 #ifdef GUI_GTK
 		// Post a repaint request from any thread.
@@ -160,8 +164,11 @@ namespace gui {
 		void initCommonControls();
 
 		// Window proc.
+		typedef LRESULT (WINAPI *DefaultWndProc)(HWND, UINT, WPARAM, LPARAM);
 		static LRESULT WINAPI windowProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam);
-		static MsgResult handleMessage(HWND hwnd, const Message &msg);
+		static LRESULT WINAPI subclassProc(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lParam, UINT_PTR subclass, DWORD_PTR refData);
+		static LRESULT handleMessage(HWND hwnd, const Message &msg, DefaultWndProc defProc);
+		static MsgResult handleMessageI(HWND hwnd, const Message &msg, Window *&found);
 #endif
 	};
 
