@@ -20,12 +20,13 @@ namespace gui {
 		virtual bool onCommand(nat id);
 #endif
 #ifdef GUI_GTK
-		using Window::text;
-		void text(Str *text);
-
 		virtual GtkWidget *fontWidget();
 #endif
 
+		// Set text.
+		virtual void STORM_FN text(Str *text);
+		using Window::text;
+
 		// Checked?
 		Bool STORM_FN checked();
 
