@@ -38,6 +38,9 @@ namespace gui {
 
 		// Current DPI.
 		virtual Nat currentDpi();
+
+		// Background color.
+		virtual void windowBackground(HBRUSH &brush, COLORREF &color);
 #endif
 
 #ifdef GUI_GTK
