@@ -16,12 +16,14 @@ namespace gui {
 		Handle(ATOM atom) { value = (size_t)atom; }
 		Handle(HMENU menu) { value = (size_t)menu; }
 		Handle(HINSTANCE instance) { value = (size_t)instance; }
+		Handle(HBRUSH brush) { value = (size_t)brush; }
 
 		// Get Win32 types.
 		inline HWND hwnd() const { return (HWND)value; }
 		inline ATOM atom() const { return (ATOM)value; }
 		inline HMENU menu() const { return (HMENU)value; }
 		inline HINSTANCE instance() const { return (HINSTANCE)value; }
+		inline HBRUSH brush() const { return (HBRUSH)value; }
 #endif
 
 #ifdef GUI_GTK
