@@ -216,11 +216,34 @@ namespace gui {
 		}
 		case WM_PAINT:
 			return onPaint();
+		case WM_ERASEBKGND: {
+			// Much like the default message proc, but respects 'windowColor'.
+			HWND wnd = handle().hwnd();
+			HDC dc = (HDC)msg.wParam;
+
+			HBRUSH brush;
+			COLORREF color;
+			windowBackground(brush, color);
+
+			RECT rect;
+			GetClientRect(wnd, &rect);
+			FillRect(dc, &rect, brush);
+
+			return msgResult(1);
+		}
 		case WM_TIMER: {
 			if (msg.wParam == 1) {
 				onTimer();
 				return msgResult(0);
 			}
+		}
+		case WM_CTLCOLORSTATIC: {
+			HBRUSH brush;
+			COLORREF color;
+			windowBackground(brush, color);
+			HDC dc = HDC(msg.wParam);
+			SetBkColor(dc, color);
+			return msgResult((LRESULT)brush);
 		}
 			// TODO: Propagate mouse messages to parent windows?
 		case WM_LBUTTONDOWN:
@@ -314,6 +337,8 @@ namespace gui {
 		return noResult();
 	}
 
+	void Window::afterMessage(const Message &msg) {}
+
 	void Window::visible(Bool show) {
 		myVisible = show;
 		if (created())
@@ -450,6 +475,16 @@ namespace gui {
 			font(myFont);
 	}
 
+	void Window::windowBackground(HBRUSH &brush, COLORREF &color) {
+		if (myParent && myParent != this) {
+			return myParent->windowBackground(brush, color);
+		} else {
+			// Avoid crashes and provide a somewhat sane defaults:
+			color = GetSysColor(gui::windowBackground);
+			brush = GetSysColorBrush(gui::windowBackground);
+		}
+	}
+
 	bool Window::create(ContainerBase *parent, nat id) {
 		return createEx(NULL, childFlags, 0, parent->handle().hwnd(), id);
 	}
@@ -545,6 +580,10 @@ namespace gui {
 			return false;
 		}
 
+		if (flags & cWin32Subclass) {
+			app->subclass(z);
+		}
+
 		if (WS_CHILD & ~style) {
 			// Take DPI into account.
 			Nat dpi = windowDpi(z);
@@ -911,6 +950,10 @@ namespace gui {
 		return false;
 	}
 
+	void Window::updateGtkMinSize() {
+		// Nothing here.
+	}
+
 	gboolean Window::onDraw(cairo_t *ctx) {
 		GdkWindow *window = gdkWindow;
 		if (!window)
