@@ -27,6 +27,9 @@ namespace sql {
 		// Check if the connection is a local pipe.
 		MAYBE(Str *) STORM_FN isLocal() const;
 
+		// Output.
+		void STORM_FN toS(StrBuf *to) const;
+
 	private:
 		// Create a default initialized connection.
 		Host();
@@ -38,7 +41,4 @@ namespace sql {
 		Object *data;
 	};
 
-	// Output.
-	StrBuf *operator <<(StrBuf *to, const Host &c);
-
 }
