@@ -1,6 +1,20 @@
 #include "stdafx.h"
 #include "Compiler/Package.h"
 
+void compileNoRes(Package *in) {
+	in->forceLoad();
+	for (NameSet::Iter i = in->begin(); i != in->end(); i++) {
+		if (Package *child = as<Package>(i.v())) {
+			if (child->name->endsWith(S("_res")) || *child->name == S("res")) {
+			} else {
+				compileNoRes(child);
+			}
+		} else {
+			i.v()->compile();
+		}
+	}
+}
+
 /**
  * Compile all code and see what happens.
  */
@@ -49,3 +63,18 @@ BEGIN_TEST(SQL, Compile) {
 	Engine &e = gEngine();
 	CHECK_RUNS(e.package(S("sql"))->compile());
 } END_TEST
+
+BEGIN_TEST(Parser, Compile) {
+	Engine &e = gEngine();
+	CHECK_RUNS(e.package(S("parser"))->compile());
+} END_TEST
+
+BEGIN_TEST(Markdown, Compile) {
+	Engine &e = gEngine();
+	CHECK_RUNS(compileNoRes(e.package(S("markdown"))));
+} END_TEST
+
+BEGIN_TEST(Tutorials, Compile) {
+	Engine &e = gEngine();
+	CHECK_RUNS(compileNoRes(e.package(S("tutorials"))));
+} END_TEST
