@@ -48,10 +48,12 @@ SUITE(Storm, 8);
 SUITE(SimpleBS, 9);
 // More heavy tests of Basic Storm
 SUITE(BS, 10);
+// Test suites inside Storm.
+SUITE(BSSuites, 11);
 // Some compilation tests that make sure the provided code compiles. Nice to have these last.
-SUITE(Compile, 11);
+SUITE(Compile, 12);
 // Language server logic.
-SUITE(Server, 12);
+SUITE(Server, 13);
 
 // UI library. Sadly not too many automated tests.
 SUITED(Gui, 20);
